==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
var EditRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EditRowDefinitionDescriptionMetadata, _super);
    function EditRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditRowDefinitionDescriptionMetadata.b = function (a) {
        if (EditRowDefinitionDescriptionMetadata.a == null) {
            EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
        }
        if (a.j(EditRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.y(EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditRowDefinitionDescriptionMetadata.d = function (a) {
        EditRowDefinitionDescriptionMetadata.b(a);
        a.aa("EditRowDefinition", function () { return new EditRowDefinitionDescription(); });
        a.z("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.$t = markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
}(Base));
export { EditRowDefinitionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
var EditRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EditRowDefinitionDescriptionMetadata, _super);
    function EditRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditRowDefinitionDescriptionMetadata.b = function (a) {
        if (EditRowDefinitionDescriptionMetadata.a == null) {
            EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
        }
        if (a.k(EditRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.aa(EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditRowDefinitionDescriptionMetadata.d = function (a) {
        EditRowDefinitionDescriptionMetadata.b(a);
        a.ac("EditRowDefinition", function () { return new EditRowDefinitionDescription(); });
        a.ab("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.$t = markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
}(Base));
export { EditRowDefinitionDescriptionMetadata };
